@@ -1,8 +1,8 @@
 from fosvis import seq_util
-import links
-import protein_domains
-import orf
-import diagram_and_legend
+from fosvis import links
+from fosvis import protein_domains
+from fosvis import orf
+from fosvis import diagram_and_legend
 
 from Bio.Blast.Applications import NcbiblastnCommandline
 from Bio.SeqUtils import GC
